function chart_pos_order_salesman (widget) {
    "use strict";

    var model = openerp;

    widget.ChartPosOrderSalesmanWidget = widget.Base.extend({
        template: 'ChartPosOrderSalesman',
        data: [],
        countPosOrder: [],
        resPartner: [],
        modelId: [],

        events: {
            
        },
        init: function (parent) {
            this._super(parent, {
                width: 6,
                height: 4
            });
        },
        start: function () {
            var self = this;
            self.fetchInitial();
        },
        fetchInitial:function() {
            var self = this;
            self.$el.block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });

            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fecthPosOrder().then(function (PosOrder) {
                return PosOrder;
            }).then(function (PosOrder) {
                self.PosOrder = PosOrder;
                return self.fecthResUser();
            }).then(function (ResUser) {
                self.ResUser = ResUser;
                return self.fetchProductRanking();
            });
        },

        // Obtener Pedidos
        fecthPosOrder: function() {
            var self = this;
            var desde = moment().format('YYYY-MM-01 00:00:00');
            var hasta = moment().add(1,'months').format('YYYY-MM-01 00:00:00');
            var defer = $.Deferred();
            var fields = ['id','date_order','partner_id','amount_total','user_id'];
            var domain = [['state', 'in', ['paid','done','invoiced']], ['partner_id', '!=', false], ['date_order', '>=', desde], ['date_order', '<', hasta]];
            var PosOrder = new model.web.Model('pos.order');
            PosOrder.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });

            return defer;
        },
        // Consultar Clientes
        fecthResUser: function() {
            var self = this;
            var defer = $.Deferred();
            var user_ids = _.map(self.PosOrder,function(map){
                return map.user_id[0];
            });
            var fields = ['id', 'name'];
            var domain = [['id', 'in', user_ids]];
            var ResUsers = new model.web.Model('res.users');
            ResUsers.query(fields).filter(domain).all().then(function(results) {
                defer.resolve(results);
            });

            return defer;
        },
        getPosOrder:function(partner_id) {
            var self = this;
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return inv.user_id[0] === partner_id;
            }));
        },
        // Generar el Ranking
        fetchProductRanking: function() {
            var self = this;
            var itemPartner;
            var itemPosOrder;
            var countPosOrder = 0
            var ranking = [];

            for (var i = 0; i < self.ResUser.length; i++) {
                itemPartner = self.ResUser[i];
                itemPosOrder = self.getPosOrder(itemPartner.id);

                var quantity = _.reduce(_.map(itemPosOrder,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);

                ranking.push({
                    id: itemPartner.id,
                    name: itemPartner.name,
                    countPosOrder: quantity
                });
            }
            ranking.sort(function (a, b) {
                return b.countPosOrder - a.countPosOrder
            });
            self.ranking = ranking;

            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.$el.find('.widget-title').find('span').text("Ventas por Vendedor");
            self.fetchChart(ranking);
        },
        // Generar Grafico
        fetchChart: function (ranking) {
            var self = this;
            var label = [];
            var body = [];
            var item;
            var rank = 5;

            if (ranking.length < rank && ranking.length > 0 )
                rank= ranking.length;

            for (var i = 0; i < rank; i++) {
                if (ranking[i]) {
                    item = ranking[i];
                }
                if (ranking.length === 0) {
                    item = {};
                    item.name = "N/A";
                    item.countPosOrder = 0;
                }
                label.push(item.name);
                body.push(item.countPosOrder);
            }
            // Global method for setting Y axis number format.
            Chart.scaleService.updateScaleDefaults('linear', {
              ticks: {
                callback: function(tick) {
                    return tick.toLocaleString('de-DE');
                }
              }
            });
            Chart.defaults.global.tooltips.callbacks.label = function(tooltipItem, data) {
                var dataset = data.datasets[tooltipItem.datasetIndex];
                var datasetLabel = dataset.label || '';
                return datasetLabel +  dataset.data[tooltipItem.index].toLocaleString('de-DE');
            };
            var chart = new Chart(this.$el.find(".widget-content").find('canvas'), {
                type: 'horizontalBar',
                data: {
                    labels: label,
                    datasets: [
                        {
                            label: 'Ventas  ',
                            backgroundColor: '#e3f2fd',
                            borderColor: '#64b5f6',
                            hoverBackgroundColor: '#c8e6c9',
                            hoverBorderColor: '#66bb6a',
                            borderWidth: 2,
                            data: body,
                        }
                    ]
                },
                options: {
                    responsive: true,
                    hover: {
                        mode: 'nearest',
                        intersect: true
                    },
                    layout: {
                        padding: {
                            top: 30,
                            bottom: 10,
                            left : 0,
                            rigth: 0,
                        }
                    },
                }
            });
        },
    });
}
